# Hands-on ?: Verification Workflow with SUNSET

## Goal
Create a SUNSET recipe and use the functions in the suite to reproduce the verification workflow from the previous hands-on exercises.

## 0. Copy the recipe template and modify it

```shell
# Go to the SUNSET directory
cd $SUNSET_DIR
# Create a copy of the recipe in your directory, adding your name in <user_name>
cp use_cases/PATC_2023/recipe_PATC_2023.yml use_cases/PATC_2023/recipe_PATC_2023-<user_name>.yml
# Open the recipe with a text editor such as vim
vim use_cases/PATC_2023/recipe_PATC_2023-<user_name>.yml
```

Text

```yaml

```

## 1. Load the required SUNSET modules and read the recipe

```r
# Load modules
source("modules/Loading/Loading.R")
source("modules/Units/Units.R")
source("modules/Calibration/Calibration.R")
source("modules/Anomalies/Anomalies.R")
source("modules/Skill/Skill.R")
source("modules/Saving/Saving.R")
source("modules/Visualization/Visualization.R")

# Read recipe
recipe_file <- "use_cases/PATC_2023/recipe_PATC_2023-<______>.yml"
recipe <- prepare_outputs(recipe_file)

```
**Questions**

1. Did your recipe pass the check? Did you get any warnings? 

## 2. Load the data and change the units

```r
# Load datasets
data <- Loading(recipe)
# Change units
data <- Units(recipe, data)
```

**Questions**

1. What is the structure of `data`? Tip: you can use functions like class() and names() to gain information about the structure of the object and its contents.

1. Did your data get converted? If the units you requested are the same as the original data, no unit conversion is needed. Otherwise, the Units module handles the conversion for you. Are the new units what you expect? You can check the metadata of any of the objects in data. SUNSET also provides the data_summary() function, which lets you have a quick look at your objects:

```r
# Check the new units and data
data$fcst$attrs$Variable$metadata$tas$units
data_summary(data$fcst, recipe)
```

## 3. Calibrate the data
# Calibrate datasets

```r
data <- Calibration(recipe, data)
# Compute anomalies
data <- Anomalies(recipe, data)
# Compute skill metrics 
skill_metrics <- Skill(recipe, data)
# Compute percentiles and probability bins
probabilities <- Probabilities(recipe, data)
# Plot data
Visualization(recipe, data, skill_metrics, probabilities, significance = T)
```



